Given training data X with true labels REALCLASS, add new records to X and REALCLASS, which are noisy copies of the training data.
addNoisyCopies(realclass, x, pars)a matrix containing the training data
true class of training data (can be vector, numerics, integers, factors)
list of parameters:
pars$ncopies: Number of new records to add
pars$ncsort: Defines if training data should be sorted by class. Default is FALSE
pars$ncsigma: The noise in each column of x has the std.dev. pars$ncsigma*(standard deviation of column). Default Value: 0.8
pars$ncmethod: =1: each 'old' record from X in turn is the centroid for a new pattern;
=2: the centroid is the average of all records from the same class, the std.dev. is the same for all classes;
=3: centroid as in '2', the std.dev. is the std.dev. of all records from the same class (*recommended*)
list res
- res contains two list entries: realclass and x (including added copies)